function  AR_F(rho_true, n, m, pi_H,rho_H)
% For a given true value of the AR parameter, this program simulates the finite-sample distribution of the estimators and the t and QLR statistics, calculate the finite-sample coverage probability of the standard, least favorable, and type 2 robust CIs with different kappa values. 
% by Donald Andrews and Xu Cheng
% INPUTS: 
% rho_true is the true value of the AR coef
% m is number of simulation repetitions
% n is the finite-sample size
% pi_H is the upper bound of the opt space for MA coef
% rho_H is the upper bound of the opt space for AR coef

pi_L= -pi_H;
rho_L = -rho_H;
TN1 = round(100*rho_true);
%% parameter set-up
alpha = 0.05;
zeta_true= 1; % this is the variance of error: e
opt = optimset('LargeScale','off', ...
               'HessUpdate','bfgs', ...
               'Algorithm', 'active-set',...
               'Hessian','off', ...
               'GradObj','on', ...
               'DerivativeCheck','off',...
               'Display', 'off');
    
%grids for b values
upp1 = 5;
upp2 = 10;
upp3 = 20;
stepsi1 = 0.1;
stepsi2 = 0.2;
stepsi3 = 1;
b1 = 0:stepsi1:upp1;
b2 = upp1+stepsi2:stepsi2:upp2;
b3 = upp2+stepsi3:stepsi3:upp3;
b_V = [b1,b2,b3]';
rb = rows(b_V);

%only consider b values for which there exists valid true values of rho in
%the true parameter space given that rho = beta + pi.
i_V = b_V;
for k = 1:rb
    h = b_V(k);
    beta_true = h/sqrt(n);
    pi_true = rho_true -  beta_true;
    if abs(pi_true)>pi_H
        i_V(k)=1;
    else i_V(k)=0;
    end
end
b_V(i_V>0)=[];
[rb cb] = size(b_V);

%matrix used in the optimization below
A = [1,1;
    -1,-1;
    0,1;
    0,-1;];
bb = [rho_H; -rho_L; pi_H; -pi_L];
A1 = [0,1;
    0,-1;];
b1 = [pi_H; -pi_L];
C1 = [1,1];

nd = 200; % get rid of initial effect
Y = ones(n+nd-1,1);
TbM_F = zeros(rb,3,m);  A_F = zeros(rb,1,m); TbM_qlr_F = zeros(rb,1,m); 
TbM_qlr_pi_F = zeros(rb,1,m); Theta_M=zeros(rb,3,m); 

%% Simulation Repetition Starts
z=1;
while z<m+0.1;
%% DGP %%%
e = sqrt(zeta_true)*randn(n+nd,1);
e1=e(2:end);
e2=e(1:end-1);
e0 = e(1);
Y(1) = e(1);
rnd = rand(10,2); % random number for starting points in global minimization

parfor k = 1:rb
    b = b_V(k,1);
    beta_true = b/sqrt(n);
    pi_true = rho_true -  beta_true;
    
    error = e1-pi_true*e2;
    error2 = [e0;error];
    Y = zeros(n+nd,1);
    for t=1:n+nd
        power = t-1:-1:0;      
        rho_power = [rho_true.^power,zeros(1,n+nd-t)];
        Y(t)=rho_power*error2;
    end
lz=100; %lags beyond lz are truncated for computational ease
Y = Y(end:-1:end-n-lz,1); 
Y_lag = zeros(lz,n);
for i =1:n
    Y_lag(:,i) = Y(i+1:i+lz);
end

Y_up = Y(1:n);
pow = 1:lz;
theta_true = [beta_true, zeta_true, rho_true];
 
%% resticted estimator beta = beta_true
pb_H = min(pi_H, rho_H - beta_true);
pb_L = max(pi_L, rho_L - beta_true);

Q_beta = cf_pi(Y_up,Y_lag, pow, pi_true, beta_true);
theta_qlr_beta = pi_true;

%grid search for starting values
for i=0:0.02:1
    pi =pb_L+i*(pb_H-pb_L);  
    Q_beta1 = cf_pi(Y_up,Y_lag, pow, pi, beta_true);
    if Q_beta1 <Q_beta       
       theta_qlr_beta = pi;
       Q_beta = Q_beta1;       
    end    
end    
[theta_qlr_beta, Q_beta] = fmincon(@(pi)cf_pi(Y_up,Y_lag, pow, pi, beta_true),theta_qlr_beta, [], [], [], [], pb_L, pb_H, [], opt);

%% resticted estimator rho = rho_true
theta_qlr_pi = [beta_true,pi_true];
[theta_qlr_pi, Q_pi] = fmincon(@(theta)cf_theta(Y_up, Y_lag, pow,theta),theta_qlr_pi, A1, b1, C1, rho_true, [], [], [], opt);

for j =1:10;    
    pi0 = pi_L+rnd(j,1)*(pi_H-pi_L);
    beta0 = rho_true - pi0;   
    theta0=[beta0,pi0]; 
        [theta_qlr_pi1 Q_pi1] = fmincon(@(theta)cf_theta(Y_up, Y_lag, pow,theta),theta0, A1, b1, C1, rho_true, [], [], [], opt);
        if Q_pi1 < Q_pi
           theta_qlr_pi = theta_qlr_pi1;
           Q_pi = Q_pi1;
        end   
end

%% unrestricted estimator
theta_star_true = [beta_true, pi_true];
[theta_star, Q_unres] = fmincon(@(theta)cf_theta(Y_up, Y_lag, pow,theta),theta_star_true, A, bb, [], [], [], [], [], opt);
for j =1:10;    
    pi0 = pi_L+rnd(j,1)*(pi_H-pi_L);
    beta0 = rho_L + rnd(j,2)*(rho_H-rho_L)-pi0;
    theta0=[beta0,pi0];
        [theta_star1 Q_unres1] = fmincon(@(theta)cf_theta(Y_up, Y_lag, pow,theta),theta0, A, bb, [], [], [], [], [], opt);
        if Q_unres1 < Q_unres
           theta_star = theta_star1;
           Q_unres = Q_unres1;
        end  
end
beta_star = theta_star(1);
zeta_star = Q_unres/n; % Q = sum square errors
pi_star = theta_star(2);
rho_star = beta_star + pi_star;
theta_star2 = [beta_star, zeta_star, rho_star];

%% QLR for Beta
qlr = n*(log(Q_beta)-log(Q_unres));
if qlr<0 %This only happens rarely due to computational errors
    qlr=0;
end

%% QLR for rho
qlr_pi = n*(log(Q_pi) - log(Q_unres));
if qlr_pi<0
    qlr_pi=0;
end

%% QLR statistic
QLR = [qlr,qlr_pi];

%% t statistic
pi_pow = pi_star.^(pow-1);
Y_lag_pi = (pi_pow*Y_lag)';
p2=pow(2:end);
pi_pow_j = [0,(p2-1).*pi_star.^(p2-2)];
Y_der_pi = (pi_pow_j*Y_lag)';

J1 = Y_lag_pi'*Y_lag_pi/n/zeta_star;
J2 = 1/2/zeta_star^2;
J3 = Y_der_pi'*Y_der_pi/n/zeta_star;
J4 = Y_lag_pi'*Y_der_pi/n/zeta_star;
rot = [0,0,1;
       0,0,0;
       1,0,0];
J = diag([J1,J2,J3])+J4*rot;

Rt1 = [1,0,0;
        0,1,0;
        1,0,1];
Rt2 = diag([ones(1,2),1/abs(beta_star)]);
var = Rt1*Rt2*inv(J)*Rt2'*Rt1'/n;
se = sqrt(diag(var))';

t = (theta_star2-theta_true) ./se;
pre_t = abs(theta_star2./se); % centered at 0 rather than the true value, used for identification category selection

%%% end of the test statistics

%% stack statistic together
TbM_F(k,:,z)= t;
A_F(k,:,z)=pre_t(1); 
TbM_qlr_pi_F(k,:,z)=qlr_pi;
Theta_M(k,:,z)=theta_star2;

end  % finish loop over b

z=z+1;
end  % finish loop over z

%% finite coverage probabilities for standard, least favorable, and type-II robust CIs for pi

%parameters in robust CIs
K_V = [0,0.5,1,1.5,1.75,2,2.25,2.5,2.75,3,4,5,6,8,10];
c = 0.5;
ind =1;
load ('LF_SizeCorrection.mat');

% symmetric two-sided t CIs
W = abs(TbM_F(:,3,:));
std_cv = icdf('normal', 1-alpha/2, 0,1);
LF_cv = LF_abs_piV(2,ind);
tao_V_abs = [abs_tau1(:,ind),abs_tau2(:,ind)];
covprob_F_abs = covprob(W, A_F, std_cv, LF_cv, K_V, tao_V_abs, c,ind); %tao_V_abs is obtained from Asy_ARMA.mat

% QLR CIs
W = TbM_qlr_pi_F;
std_cv =  icdf('chi2', 1-alpha, 1);
LF_cv = LF_qlr_piV(2,ind);
tao_V_qlr = [qlr_tau1(:,ind),qlr_tau2(:,ind)];
covprob_F_qlr =  covprob(W, A_F, std_cv, LF_cv, K_V, tao_V_qlr, c,ind);%tao_V_qlr is obtained from Asy_ARMA.mat

save(sprintf('AR_F_%d_%d.mat',n, TN1),'TbM_F','A_F', 'TbM_qlr_pi_F', 'Theta_M',...
     'covprob_F_abs','covprob_F_qlr',...
     'rho_true','K_V');
