function [A_F, Q_FCP_M,t_FCP_M]= AR_FCP(rho_true, rho_null_V, b_VV, n, m, pi_H,rho_H)
% For a given true value of the AR parameter, this program simulates the
% finite-sample distribution of the t and QLR statistics under various
% null values of the AR parameter that are different from the true value.
% by Donald Andrews and Xu Cheng
% INPUTS: 
% rho_true is the true value of the AR coef
% rho_null_V: a vector of null values for rho
% m is number of simulation repetitions
% n is the finite-sample size
% pi_H is the upper bound of the opt space for MA coef
% rho_H is the upper bound of the opt space for AR coef

pi_L= -pi_H;
rho_L = -rho_H;

%% parameter set-up
rb = rows(b_VV);
%% parameter set-up
zeta_true= 1; % this is the variance of error: e
opt = optimset('LargeScale','off', ...
               'HessUpdate','bfgs', ...
               'Algorithm', 'active-set',...
               'Hessian','off', ...
               'GradObj','on', ...
               'DerivativeCheck','off',...
               'Display', 'off');
           
%matrix used in the optimization below
A = [1,1;
    -1,-1;
    0,1;
    0,-1;];
bb = [rho_H; -rho_L; pi_H; -pi_L];
A1 = [0,1;
    0,-1;];
b1 = [pi_H; -pi_L];
C1 = [1,1];

nd = 200; % get rid of initial effect
Y = ones(n+nd-1,1);
TbM_F = zeros(rb,3,m);  A_F = zeros(rb,1,m); TbM_qlr_F = zeros(rb,1,m); 
TbM_qlr_pi_F = zeros(rb,1,m); Theta_M=zeros(rb,3,m); 
Q_FCP_M = zeros(rb,length(rho_null_V),m);
t_FCP_M = zeros(rb,length(rho_null_V),m);


%% Simulation Repetition Starts
z=1;
while z<m+0.1;
%% DGP %%%
e = sqrt(zeta_true)*randn(n+nd,1);
e1=e(2:end);
e2=e(1:end-1);
e0 = e(1);
Y(1) = e(1);
rnd = rand(10,2); % random number for starting points in global minimization

for k = 1:rb
    b = b_VV(k,1);
    beta_true = b/sqrt(n);
    pi_true = rho_true -  beta_true;
    
    error = e1-pi_true*e2;
    error2 = [e0;error];
    Y = zeros(n+nd,1);
    for t=1:n+nd
        power = t-1:-1:0;      
        rho_power = [rho_true.^power,zeros(1,n+nd-t)];
        Y(t)=rho_power*error2;
    end
lz=100; %lags beyond lz are truncated for computational ease
Y = Y(end:-1:end-n-lz,1); 
Y_lag = zeros(lz,n);
for i =1:n
    Y_lag(:,i) = Y(i+1:i+lz);
end

Y_up = Y(1:n);
pow = 1:lz;
theta_true = [beta_true, zeta_true, rho_true];
 

%% resticted estimator rho = rho_true
theta_qlr_pi = [beta_true,pi_true];
[theta_qlr_pi, Q_pi] = fmincon(@(theta)cf_theta(Y_up, Y_lag, pow,theta),theta_qlr_pi, A1, b1, C1, rho_true, [], [], [], opt);

for j =1:10;    
    pi0 = pi_L+rnd(j,1)*(pi_H-pi_L);
    beta0 = rho_true - pi0;   
    theta0=[beta0,pi0]; 
        [theta_qlr_pi1 Q_pi1] = fmincon(@(theta)cf_theta(Y_up, Y_lag, pow,theta),theta0, A1, b1, C1, rho_true, [], [], [], opt);
        if Q_pi1 < Q_pi
           theta_qlr_pi = theta_qlr_pi1;
           Q_pi = Q_pi1;
        end   
end

%% unrestricted estimator
theta_star_true = [beta_true, pi_true];
[theta_star, Q_unres] = fmincon(@(theta)cf_theta(Y_up, Y_lag, pow,theta),theta_star_true, A, bb, [], [], [], [], [], opt);
for j =1:10;    
    pi0 = pi_L+rnd(j,1)*(pi_H-pi_L);
    beta0 = rho_L + rnd(j,2)*(rho_H-rho_L)-pi0;
    theta0=[beta0,pi0];
        [theta_star1 Q_unres1] = fmincon(@(theta)cf_theta(Y_up, Y_lag, pow,theta),theta0, A, bb, [], [], [], [], [], opt);
        if Q_unres1 < Q_unres
           theta_star = theta_star1;
           Q_unres = Q_unres1;
        end  
end
beta_star = theta_star(1);
zeta_star = Q_unres/n; % Q = sum square errors
pi_star = theta_star(2);
rho_star = beta_star + pi_star;
theta_star2 = [beta_star, zeta_star, rho_star];


%% QLR for rho
qlr_pi = n*(log(Q_pi) - log(Q_unres));
if qlr_pi<0
    qlr_pi=0;
end
%% t statistic
pi_pow = pi_star.^(pow-1);
Y_lag_pi = (pi_pow*Y_lag)';
p2=pow(2:end);
pi_pow_j = [0,(p2-1).*pi_star.^(p2-2)];
Y_der_pi = (pi_pow_j*Y_lag)';

J1 = Y_lag_pi'*Y_lag_pi/n/zeta_star;
J2 = 1/2/zeta_star^2;
J3 = Y_der_pi'*Y_der_pi/n/zeta_star;
J4 = Y_lag_pi'*Y_der_pi/n/zeta_star;
rot = [0,0,1;
       0,0,0;
       1,0,0];
J = diag([J1,J2,J3])+J4*rot;

Rt1 = [1,0,0;
        0,1,0;
        1,0,1];
Rt2 = diag([ones(1,2),1/abs(beta_star)]);
var = Rt1*Rt2*inv(J)*Rt2'*Rt1'/n;
se = sqrt(diag(var))';

pre_t = abs(theta_star2./se); % centered at 0 rather than the true value, used for identification category selection

se_pi = se(3);
%% FCP 
% resticted estimator rho = rho_null

Q_FCP_V = zeros(1,length(rho_null_V));
t_FCP_V = zeros(1,length(rho_null_V));
parfor q = 1:length(rho_null_V);
    rho_null = rho_null_V(q);
    pi_null = rho_null - beta_true;

    % resticted estimator rho = rho_true
    theta_qlr_pi = [beta_true,pi_null];
    [theta_qlr_pi, Q_FCP] = fmincon(@(theta)cf_theta(Y_up, Y_lag, pow,theta),theta_qlr_pi, A1, b1, C1, rho_null, [], [], [], opt);
    qlr_pi = n*(log(Q_FCP) - log(Q_unres));
    if qlr_pi<0 %This only happens rarely due to computational errors
        qlr_pi=0;
    end

    Q_FCP_V(q) = qlr_pi;
    t_FCP_V(q) = (rho_star - rho_null)/se_pi;
end

%% stack statistic together
A_F(k,:,z)=pre_t(1); 

Q_FCP_M(k,:,z) = Q_FCP_V;
t_FCP_M(k,:,z) = t_FCP_V;

end  % finish loop over b

z=z+1;
end  % finish loop over z
