%This program plots Figures 1, 2, 3, 5, and S1-S6
%"Estimation and Inference with Weak, Semi-strong, and Strong
%Identification" by Donald Andrews and Xu Cheng

clear; clc;

pi_H = 0.85;
rho_H= 0.9;
n = 250;
m = 50000;

%% Generate Data for Figures 1,2,3,5
pi_true = 0.4;
TN1 = round(pi_true*100);
ARMA_Asy(pi_true, m, pi_H); % simulate asy results, save file ARMA_Asy_TN1.mat
MA_F(pi_true, n, m, pi_H,rho_H); % simulate finite-sample results, save file MA_F_n_TN1.mat

%% Figure 1. Asymptotic and Finite-Sample (n=250) Densities of the Estimator of pi in the ARMA(1,1) Model when pi_true = 0.4
load(sprintf('ARMA_Asy_%d.mat',TN1));
load(sprintf('MA_F_%d_%d.mat',n,TN1));

bR = [0,2,4,12];
IR = [1,21,41,78]; %index of [0,2,4,12] in the grids considered (b_V vector)
xmin = -1;
xmax =1;
ymin = 0;
ymax = 6;

%asymptotic results, first row
A = TbM_piest;
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t);
B = A(k,:,:);
B = reshape(B,m,1);
[nn,x]=hist(B,40);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','b','EdgeColor','b');
axis([xmin,xmax,ymin,ymax]);
title(sprintf('Asy, b=%d',-b));
end

%finite-sample results, second row
C = Theta_M(:,3,:);
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t+4);
B = C(k,:,:);
B = reshape(B,m,1);
[nn,x]=hist(B,40);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','r','EdgeColor','r');
axis([xmin,xmax,ymin,ymax]);
title(sprintf('n=250, b=%d',-b));
end
saveas(gcf,'AC_Figure_1.fig');
%end of Figure 1

%% Figure 2. Asymptotic and Finite-Sample (n=250) Densities of the Estimator of beta in the ARMA(1,1) Model when pi_true = 0.4
xmin = -0.3;
xmax =0.3;
ymin = 0;
ymax = 8;

%asymptotic results, first row
A = TbM(:,1,:).*TbM_se(:,1,:);
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t);
B = A(k,:,:);
B = reshape(B,m,1);
B = -B/sqrt(n);
[nn,x]=hist(B,100);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','b','EdgeColor','b');
axis([xmin,xmax,ymin,ymax]);
title(sprintf('Asy, b=%d',-b));
end

% finite-sample results, second row
C = Theta_M(:,1,:);
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t+4);
B = C(k,:,:);
B = reshape(B,m,1);
B = B+b/sqrt(n);
[nn,x]=hist(B,100);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','r','EdgeColor','r');
axis([xmin,xmax,ymin,ymax]);
title(sprintf('n=250, b=%d',-b));
end
saveas(gcf,'AC_Figure_2.fig');

%end of table 2




%% Figure 3. Asymptotic and Finite-Sample (n=250) Densities of the t statistic for the MA parameter pi in the ARMA(1,1) model when pi_true =0.4
xmin = -10;
xmax = 10;
ymin = 0;
ymax = 0.5;

%asymptotic results, first row
A = TbM(:,3,:);
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t);
B = A(k,:,:);
B = reshape(B,m,1);
[nn,x]=hist(B,100);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','b','EdgeColor','b');
axis([xmin,xmax,ymin,ymax]);
title(sprintf('Asy, b=%d',-b));
xline = -10:0.01:10;
yline = 1/sqrt(2*pi)*exp(-xline.^2/2);
line (xline, yline, 'LineWidth',2, 'Color','k');
end

%finite-sample results, second row
C = TbM_F(:,3,:);
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t+4);
B = C(k,:,:);
B = reshape(B,m,1);
[nn,x]=hist(B,100);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','r','EdgeColor','r');
axis([xmin,xmax,ymin,ymax]);
xline = -10:0.01:10;
yline = 1/sqrt(2*pi)*exp(-xline.^2/2);
line (xline, yline, 'LineWidth',2, 'Color','k');
title(sprintf('n=250, b=%d',-b));
end
saveas(gcf,'AC_Figure_3.fig');

% end of figure 3


%% Figure 5. Asymptotic and Finite-Sample (n=250) Densities of the QLR statistic for the MA parameter pi in the ARMA(1,1) model when pi_true = 0.4

xmin = 0;
xmax = 5;
ymin = 0;
ymax = 2;

%asymptotic results, first row
A = TbM_qlr_pi;
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t);
B = A(k,:,:);
B = reshape(B,m,1);
[nn,x]=hist(B,100);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','b','EdgeColor','b');
axis([xmin,xmax,ymin,ymax]);
title(sprintf('Asy, b=%d',-b));
xline = 0:0.01:5;
yline = chi2pdf(xline,1);
line (xline, yline, 'LineWidth',2, 'Color','k');
end

%finite-sample results, second row
C = TbM_qlr_pi_F(:,1,:);
for t = 1:4
k = IR(t);
b = bR(t);
axis([xmin,xmax,ymin,ymax]);
subplot(2,4,t+4);
B = C(k,:,:);
B = reshape(B,m,1);
[nn,x]=hist(B,100);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','r','EdgeColor','r');
axis([xmin,xmax,ymin,ymax]);
xline = 0:0.01:5;
yline = chi2pdf(xline,1);
line (xline, yline, 'LineWidth',2, 'Color','k');
title(sprintf('n=250, b=%d',-b));
end

saveas(gcf,'AC_Figure_5.fig');
%end of Figure 5


%% Generate Data for Figures S1-S6
pi_true = 0;
ARMA_Asy(pi_true, m, pi_H); % simulate asy results, save file ARMA_Asy_TN1.mat
MA_F(pi_true, n, m, pi_H,rho_H); % simulate finite-sample results, save file MA_F_n_TN1.mat

pi_true = 0.7;
ARMA_Asy(pi_true, m, pi_H); % simulate asy results, save file ARMA_Asy_TN1.mat
MA_F(pi_true, n, m, pi_H,rho_H); % simulate finite-sample results, save file MA_F_n_TN1.mat
% 
%% Figures S-1, S-3, S-5
pi_true = 0;
TN1= round(100*pi_true);
load(sprintf('ARMA_Asy_%d.mat',TN1));
load(sprintf('MA_F_%d_%d.mat',n,TN1));


%% Figure S-1. Asymptotic and Finite-Sample (n=250) Densities of the
%% Estimator of pi in the ARMA(1,1) Model when pi_true = 0
bR = [0,2,4,12];
IR = [1,21,41,78]; %index of [0,2,4,12] in the grids considered (b_V vector)
xmin = -1;
xmax =1;
ymin = 0;
ymax = 6;

%asymptotic results, first row
A = TbM_piest;
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t);
B = A(k,:,:);
B = reshape(B,m,1);
[nn,x]=hist(B,40);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','b','EdgeColor','b');
axis([xmin,xmax,ymin,ymax]);
title(sprintf('Asy, b=%d',-b));
end

%finite-sample results, second row
C = Theta_M(:,3,:);
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t+4);
B = C(k,:,:);
B = reshape(B,m,1);
[nn,x]=hist(B,40);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','r','EdgeColor','r');
axis([xmin,xmax,ymin,ymax]);
title(sprintf('n=250, b=%d',-b));
end
saveas(gcf,'AC_Figure_S1.fig');

%% Figure S-3. Asymptotic and Finite-Sample (n=250) Densities of the t
%% statistic for the MA parameter pi in the ARMA(1,1) model when pi_true =0
xmin = -10;
xmax = 10;
ymin = 0;
ymax = 0.5;

%asymptotic results, first row
A = TbM(:,3,:);
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t);
B = A(k,:,:);
B = reshape(B,m,1);
[nn,x]=hist(B,100);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','b','EdgeColor','b');
axis([xmin,xmax,ymin,ymax]);
title(sprintf('Asy, b=%d',-b));
xline = -10:0.01:10;
yline = 1/sqrt(2*pi)*exp(-xline.^2/2);
line (xline, yline, 'LineWidth',2, 'Color','k');
end

%finite-sample results, second row
C = TbM_F(:,3,:);
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t+4);
B = C(k,:,:);
B = reshape(B,m,1);
[nn,x]=hist(B,100);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','r','EdgeColor','r');
axis([xmin,xmax,ymin,ymax]);
xline = -10:0.01:10;
yline = 1/sqrt(2*pi)*exp(-xline.^2/2);
line (xline, yline, 'LineWidth',2, 'Color','k');
title(sprintf('n=250, b=%d',-b));
end
saveas(gcf,'AC_Figure_S3.fig');



%% Figure S-5. Asymptotic and Finite-Sample (n=250) Densities of the QLR
%% statistic for the MA parameter pi in the ARMA(1,1) model when pi_true =
%% 0

xmin = 0;
xmax = 5;
ymin = 0;
ymax = 2;

%asymptotic results, first row
A = TbM_qlr_pi;
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t);
B = A(k,:,:);
B = reshape(B,m,1);
[nn,x]=hist(B,100);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','b','EdgeColor','b');
axis([xmin,xmax,ymin,ymax]);
title(sprintf('Asy, b=%d',-b));
xline = 0:0.01:5;
yline = chi2pdf(xline,1);
line (xline, yline, 'LineWidth',2, 'Color','k');
end

%finite-sample results, second row
C = TbM_qlr_pi_F(:,1,:);
for t = 1:4
k = IR(t);
b = bR(t);
axis([xmin,xmax,ymin,ymax]);
subplot(2,4,t+4);
B = C(k,:,:);
B = reshape(B,m,1);
[nn,x]=hist(B,100);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','r','EdgeColor','r');
axis([xmin,xmax,ymin,ymax]);
xline = 0:0.01:5;
yline = chi2pdf(xline,1);
line (xline, yline, 'LineWidth',2, 'Color','k');
title(sprintf('n=250, b=%d',-b));
end

saveas(gcf,'AC_Figure_S5.fig');


%% Figures S-2, S-4, S-6
pi_true = 0.7;
TN1=round(100*pi_true);
load(sprintf('ARMA_Asy_%d.mat',TN1));
load(sprintf('MA_F_%d_%d.mat',n,TN1));


%% Figure S-2. Asymptotic and Finite-Sample (n=250) Densities of the
%% Estimator of pi in the ARMA(1,1) Model when pi_true = 0.7
bR = [0,2,4,12];
IR = [1,21,41,78]; %index of [0,2,4,12] in the grids considered (b_V vector)
xmin = -1;
xmax =1;
ymin = 0;
ymax = 6;

%asymptotic results, first row
A = TbM_piest;
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t);
B = A(k,:,:);
B = reshape(B,m,1);
[nn,x]=hist(B,40);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','b','EdgeColor','b');
axis([xmin,xmax,ymin,ymax]);
title(sprintf('Asy, b=%d',-b));
end

%finite-sample results, second row
C = Theta_M(:,3,:);
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t+4);
B = C(k,:,:);
B = reshape(B,m,1);
[nn,x]=hist(B,40);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','r','EdgeColor','r');
axis([xmin,xmax,ymin,ymax]);
title(sprintf('n=250, b=%d',-b));
end
saveas(gcf,'AC_Figure_S2.fig');

%% Figure S-4. Asymptotic and Finite-Sample (n=250) Densities of the t
%% statistic for the MA parameter pi in the ARMA(1,1) model when pi_true
%% =0.7
xmin = -10;
xmax = 10;
ymin = 0;
ymax = 0.5;

%asymptotic results, first row
A = TbM(:,3,:);
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t);
B = A(k,:,:);
B = reshape(B,m,1);
[nn,x]=hist(B,100);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','b','EdgeColor','b');
axis([xmin,xmax,ymin,ymax]);
title(sprintf('Asy, b=%d',-b));
xline = -10:0.01:10;
yline = 1/sqrt(2*pi)*exp(-xline.^2/2);
line (xline, yline, 'LineWidth',2, 'Color','k');
end

%finite-sample results, second row
C = TbM_F(:,3,:);
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t+4);
B = C(k,:,:);
B = reshape(B,m,1);
[nn,x]=hist(B,100);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','r','EdgeColor','r');
axis([xmin,xmax,ymin,ymax]);
xline = -10:0.01:10;
yline = 1/sqrt(2*pi)*exp(-xline.^2/2);
line (xline, yline, 'LineWidth',2, 'Color','k');
title(sprintf('n=250, b=%d',-b));
end
saveas(gcf,'AC_Figure_S4.fig');



%% Figure S-6. Asymptotic and Finite-Sample (n=250) Densities of the QLR
%% statistic for the MA parameter pi in the ARMA(1,1) model when pi_true =
%% 0.7

xmin = 0;
xmax = 5;
ymin = 0;
ymax = 2;

%asymptotic results, first row
A = TbM_qlr_pi;
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t);
B = A(k,:,:);
B = reshape(B,m,1);
[nn,x]=hist(B,100);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','b','EdgeColor','b');
axis([xmin,xmax,ymin,ymax]);
title(sprintf('Asy, b=%d',-b));
xline = 0:0.01:5;
yline = chi2pdf(xline,1);
line (xline, yline, 'LineWidth',2, 'Color','k');
end

%finite-sample results, second row
C = TbM_qlr_pi_F(:,1,:);
for t = 1:4
k = IR(t);
b = bR(t);
axis([xmin,xmax,ymin,ymax]);
subplot(2,4,t+4);
B = C(k,:,:);
B = reshape(B,m,1);
[nn,x]=hist(B,100);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','r','EdgeColor','r');
axis([xmin,xmax,ymin,ymax]);
xline = 0:0.01:5;
yline = chi2pdf(xline,1);
line (xline, yline, 'LineWidth',2, 'Color','k');
title(sprintf('n=250, b=%d',-b));
end

saveas(gcf,'AC_Figure_S6.fig');






