%This program plots Figures 4 and S-10
%"Estimation and Inference with Weak, Semi-strong, and Strong
%Identification" by Donald Andrews and Xu Cheng

clear; clc;

pi_H = 0.85;
m = 50000;

%% Generate Data for Figures 4 and S-10
% The data-generating section can be skipped if Tables S1 and S2 are
% generated first. Results saved there can be recycled.
qbV_abs = [];
qbV_qlr =[];
qbV_qlr_pi = [];
p = [0, 0.4,0.6,0.8];
for i = 1:4
pi_true = p(i);
ARMA_Asy(pi_true, m, pi_H);
TN1 = round(100*pi_true);
load(sprintf('ARMA_Asy_%d.mat',TN1));
qbV_abs = cat(3,qbV_abs,qb_abs);
qbV_qlr_pi = cat(3,qbV_qlr_pi,qb_qlr_pi);
qbV_qlr = cat(3,qbV_qlr,qb_qlr);
end

%% quantile of the t stat for pi in Figure 4(a)
[r c] =size (b_V);
normalquantile_abs = 1.96*ones(r,1);
normalquantile_qlr = 3.84*ones(r,1);

xmin = 0;
xmax = 15;
ymin = 0;
ymax = 12;
gridtick = 5;
gridtickY = 4;
subplot(1,2,1);
plot (b_V,qbV_abs(:,3,1),'r-',...
    b_V, qbV_abs(:,3,2), '--', b_V, qbV_abs(:,3,3), '-.',...
    b_V, qbV_abs(:,3,4), 'k:', 'LineWidth',2);
grid on;
axis([xmin,xmax,ymin,ymax]);
title('(a) |t| for \pi');
xlabel('|b|');
set(gca,'XTick',xmin:gridtick:xmax);
set(gca,'YTick',ymin:gridtickY:ymax);

legend('\pi_0=0.0','\pi_0=0.4','\pi_0=0.6','\pi_0=0.8');
line (b_V, normalquantile_abs, 'LineWidth',1.5, 'Color','k');

%% quantile of the QLR stat for pi in Figure 4(b)
xmin = 0;
xmax = 15;
ymin = 3;
ymax = 5;
gridtick = 5;
gridtickY = 0.5;
subplot(1,2,2);
plot (b_V, qbV_qlr_pi(:,1),'r-',  ...
    b_V, qbV_qlr_pi(:,2), '--', b_V, qbV_qlr_pi(:,3), '-.',...
    b_V,qbV_qlr_pi(:,4),'k:','LineWidth',2);
grid on;
axis([xmin,xmax,ymin,ymax]);
title('(b) QLR for \pi');
xlabel('|b|');      
set(gca,'XTick',xmin:gridtick:xmax);
set(gca,'YTick',ymin:gridtickY:ymax);

legend('\pi_0=0.0','\pi_0=0.4','\pi_0=0.6','\pi_0=0.8');
line (b_V, normalquantile_qlr, 'LineWidth',1.5, 'Color','k');

saveas(gcf,'AC_Figure_4.fig');


%% quantile of the t stat for beta in Figure S-10(a)
[r c] =size (b_V);
normalquantile_abs = 1.96*ones(r,1);
normalquantile_qlr = 3.84*ones(r,1);

xmin = 0;
xmax = 15;
ymin = 1.5;
ymax = 3.5;
gridtick = 5;
gridtickY = 0.5;
subplot(1,2,1);
plot (b_V,qbV_abs(:,1,1),'r-',...
    b_V, qbV_abs(:,1,2), '--', b_V, qbV_abs(:,1,3), '-.',...
    b_V, qbV_abs(:,1,4), 'k:', 'LineWidth',2);
grid on;
axis([xmin,xmax,ymin,ymax]);
title('(a) |t| for \beta');
xlabel('|b|');
set(gca,'XTick',xmin:gridtick:xmax);
set(gca,'YTick',ymin:gridtickY:ymax);

legend('\pi_0=0.0','\pi_0=0.4','\pi_0=0.6','\pi_0=0.8');
line (b_V, normalquantile_abs, 'LineWidth',1.5, 'Color','k');

%% quantile of the QLR stat for pi in Figure S-10(b)
xmin = 0;
xmax = 15;
ymin = 3;
ymax = 7;
gridtick = 5;
gridtickY = 1;
subplot(1,2,2);
plot (b_V, qbV_qlr(:,1),'r-',  ...
    b_V, qbV_qlr(:,2), '--', b_V, qbV_qlr(:,3), '-.',...
    b_V,qbV_qlr(:,4),'k:','LineWidth',2);
grid on;
axis([xmin,xmax,ymin,ymax]);
title('(b) QLR for \beta');
xlabel('|b|');      
set(gca,'XTick',xmin:gridtick:xmax);
set(gca,'YTick',ymin:gridtickY:ymax);

legend('\pi_0=0.0','\pi_0=0.4','\pi_0=0.6','\pi_0=0.8');
line (b_V, normalquantile_qlr, 'LineWidth',1.5, 'Color','k');

saveas(gcf,'AC_Figure_S10.fig');







