%This program plots Figures 6, 7, S-7, S-8, S-9.
%"Estimation and Inference with Weak, Semi-strong, and Strong
%Identification" by Donald Andrews and Xu Cheng

clear; clc;


pi_H = 0.85;
rho_H= 0.9;
m = 50000;


%% Note: The data-generating part can be skipped if Tables S3 and S4 are
%%  simulated first. Results saved there can be recycled.

pi_true = 0;
TN1 = round(pi_true*100);
%% Generate Data for Figure 6
ARMA_Asy(pi_true, m, pi_H); % simulate asy results, save file ARMA_Asy_TN1.mat
n=500;
MA_F(pi_true, n, m, pi_H,rho_H); % simulate finite-sample results, save file MA_F_n_TN1.mat
n=250;
MA_F(pi_true, n, m, pi_H,rho_H); 
n=100;
MA_F(pi_true, n, m, pi_H,rho_H); 
%% Figure 6. Coverage Probabilities of Standard |t| and QLR CI's for the Parameter pi in the ARMA(1,1) Model with pi_true = 0.
ind = 1; % 1 select the first column of the coverage prob vectors below, which is result for the standard CI.
load(sprintf('ARMA_Asy_%d.mat',TN1));
na = rows(covprob_asy_abs);
b0 = -b_V(1:na);
pi_abs0 = covprob_asy_abs(:,ind);
pi_qlr0 = covprob_asy_qlr(:,ind);

n = 500;
load(sprintf('MA_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_500= -b_V(1:na);
pi_abs_500 = covprob_F_abs(:,ind);
pi_qlr_500 = covprob_F_qlr(:,ind);

n = 250;
load(sprintf('MA_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_250= -b_V(1:na);
pi_abs_250 = covprob_F_abs(:,ind);
pi_qlr_250 = covprob_F_qlr(:,ind);

n = 100;
load(sprintf('MA_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_100= -b_V(1:na);
pi_abs_100 = covprob_F_abs(:,ind);
pi_qlr_100 = covprob_F_qlr(:,ind);

r  = rows (b0);
normal = 0.95*ones(r,1);
normalquantile_abs = 1.96*ones(r,1);
normalquantile_qlr = 3.84*ones(r,1);


%panel (a)
xmin = -15;
xmax = 0;
ymin = 0.5;
ymax = 1;
gridtick = 5;
gridtickY = 0.1;

subplot(1,2,1);
plot (b0,pi_abs0,'r-', b_500,pi_abs_500,'--',...
    b_250,pi_abs_250,'-.',b_100,pi_abs_100,'k:',...
    'LineWidth',2);
grid on;
axis([xmin,xmax,ymin,ymax]);
set(gca,'XDir','reverse')
title('(a) Standard |t| CI');
xlabel('b');       
set(gca,'XTick',xmin:gridtick:xmax);
set(gca,'YTick',ymin:gridtickY:ymax);
legend('Asy','n=500','n=250','n=100');
line (b0, normal, 'LineWidth',1.5, 'Color','k');



%panel (b)
xmin = -15;
xmax = 0;
ymin = 0.9;
ymax = 1;
gridtick = 5;
gridtickY = 0.02;
subplot(1,2,2);
plot (b0,pi_qlr0,'r-', b_500,pi_qlr_500,'--',...
    b_250,pi_qlr_250,'-.',b_100,pi_qlr_100,'k:',...
    'LineWidth',2);
grid on;
axis([xmin,xmax,ymin,ymax]);
set(gca,'XDir','reverse')
title('(b) Standard QLR CI');
xlabel('b');       %  add axis labels and plot title
set(gca,'XTick',xmin:gridtick:xmax);
set(gca,'YTick',ymin:gridtickY:ymax);
legend('Asy','n=500','n=250','n=100');
line (b0, normal, 'LineWidth',1.5, 'Color','k');

saveas(gcf,'AC_Figure_6.fig');


%% Figure 7. Coverage Probabilities of Robust |t| and QLR CI's for the Parameter pi in the ARMA(1,1) Model with pi_true = 0 and 0.4.
ind = 6; % the vector is organized as [std, LF, k=0, k=0.5, k=1, k=1.5,....], we report the 6th column for k=1.5
load(sprintf('ARMA_Asy_%d.mat',TN1));
na = rows(covprob_asy_abs);
b0 = -b_V(1:na);
pi_abs0 = covprob_asy_abs(:,ind);
pi_qlr0 = covprob_asy_qlr(:,ind);

n = 500;
load(sprintf('MA_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_500= -b_V(1:na);
pi_abs_500 = covprob_F_abs(:,ind);
pi_qlr_500 = covprob_F_qlr(:,ind);

n = 250;
load(sprintf('MA_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_250= -b_V(1:na);
pi_abs_250 = covprob_F_abs(:,ind);
pi_qlr_250 = covprob_F_qlr(:,ind);

n = 100;
load(sprintf('MA_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_100= -b_V(1:na);
pi_abs_100 = covprob_F_abs(:,ind);
pi_qlr_100 = covprob_F_qlr(:,ind);

r  = rows (b0);
normal = 0.95*ones(r,1);
normalquantile_abs = 1.96*ones(r,1);
normalquantile_qlr = 3.84*ones(r,1);

xmin = -15;
xmax = 0;
ymin = 0.9;
ymax = 1;
gridtick = 5;
gridtickY = 0.02;


%panel (a)
subplot(2,2,1);
plot (b0,pi_abs0,'r-', b_500,pi_abs_500,'--',...
    b_250,pi_abs_250,'-.',b_100,pi_abs_100,'k:',...
    'LineWidth',2);
grid on;
axis([xmin,xmax,ymin,ymax]);
set(gca,'XDir','reverse')
title('(a) Robust |t| CI, \pi_0=0');
xlabel('b');       %  add axis labels and plot title
set(gca,'XTick',xmin:gridtick:xmax);
set(gca,'YTick',ymin:gridtickY:ymax);
legend('Asy','n=500','n=250','n=100');
line (b0, normal, 'LineWidth',1.5, 'Color','k');

%panel (b)
subplot(2,2,2);
plot (b0,pi_qlr0,'r-', b_500,pi_qlr_500,'--',...
    b_250,pi_qlr_250,'-.',b_100,pi_qlr_100,'k:',...
    'LineWidth',2);
grid on;
axis([xmin,xmax,ymin,ymax]);
set(gca,'XDir','reverse')
title('(b) Robust QLR CI, \pi_0=0');
xlabel('b');       %  add axis labels and plot title
set(gca,'XTick',xmin:gridtick:xmax);
set(gca,'YTick',ymin:gridtickY:ymax);
legend('Asy','n=500','n=250','n=100');
line (b0, normal, 'LineWidth',1.5, 'Color','k');

%% Generate Data for Figures 7(c) and 7(d) (Figure 7 also uses Data for Figure 6)
pi_true = 0.4;
TN1 = round(pi_true*100);
ARMA_Asy(pi_true, m, pi_H); % simulate asymptotic results, save file ARMA_Asy_TN1.mat
n=500;
MA_F(pi_true, n, m, pi_H,rho_H); % simulate finite-sample results, save file MA_F_n_TN1.mat
n=250;
MA_F(pi_true, n, m, pi_H,rho_H); 
n=100;
MA_F(pi_true, n, m, pi_H,rho_H); 

ind = 6; % the vector is organized as [std, LF, k=0, k=0.5, k=1, k=1.5,....], we report the 6th column for k=1.5
load(sprintf('ARMA_Asy_%d.mat',TN1));
na = rows(covprob_asy_abs);
b0 = -b_V(1:na);
pi_abs0 = covprob_asy_abs(:,ind);
pi_qlr0 = covprob_asy_qlr(:,ind);

n = 500;
load(sprintf('MA_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_500= -b_V(1:na);
pi_abs_500 = covprob_F_abs(:,ind);
pi_qlr_500 = covprob_F_qlr(:,ind);

n = 250;
load(sprintf('MA_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_250= -b_V(1:na);
pi_abs_250 = covprob_F_abs(:,ind);
pi_qlr_250 = covprob_F_qlr(:,ind);

n = 100;
load(sprintf('MA_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_100= -b_V(1:na);
pi_abs_100 = covprob_F_abs(:,ind);
pi_qlr_100 = covprob_F_qlr(:,ind);


%panel (c)
subplot(2,2,3);
plot (b0,pi_abs0,'r-', b_500,pi_abs_500,'--',...
    b_250,pi_abs_250,'-.',b_100,pi_abs_100,'k:',...
    'LineWidth',2);
grid on;
axis([xmin,xmax,ymin,ymax]);
set(gca,'XDir','reverse')
title('(c) Robust |t| CI, \pi_0=0.4');
xlabel('b');       %  add axis labels and plot title
set(gca,'XTick',xmin:gridtick:xmax);
set(gca,'YTick',ymin:gridtickY:ymax);
legend('Asy','n=500','n=250','n=100');
line (b0, normal, 'LineWidth',1.5, 'Color','k');


%panel (d)
subplot(2,2,4);
plot (b0,pi_qlr0,'r-', b_500,pi_qlr_500,'--',...
    b_250,pi_qlr_250,'-.',b_100,pi_qlr_100,'k:',...
    'LineWidth',2);
grid on;
axis([xmin,xmax,ymin,ymax]);
set(gca,'XDir','reverse')
title('(d) Robust QLR CI, \pi_0=0.4');
xlabel('b');       %  add axis labels and plot title
set(gca,'XTick',xmin:gridtick:xmax);
set(gca,'YTick',ymin:gridtickY:ymax);
legend('Asy','n=500','n=250','n=100');
line (b0, normal, 'LineWidth',1.5, 'Color','k');

saveas(gcf,'AC_Figure_7.fig');

%% Figure S-7. Coverage Probabilities of Standard |t| and QLR CI's for the
%% Parameter pi in the ARMA(1,1) Model with pi_true = 0.4.
%% Same as Figure 6, but with pi_true =0.4 rather than 0.
%% Figure S-7 uses Data for Figure 7.

pi_true = 0.4;
TN1 = round(100*pi_true);
ind = 1; % 1 select the first column of the coverage prob vectors below, which is result for the standard CI.
load(sprintf('ARMA_Asy_%d.mat',TN1));
na = rows(covprob_asy_abs);
b0 = -b_V(1:na);
pi_abs0 = covprob_asy_abs(:,ind);
pi_qlr0 = covprob_asy_qlr(:,ind);

n = 500;
load(sprintf('MA_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_500= -b_V(1:na);
pi_abs_500 = covprob_F_abs(:,ind);
pi_qlr_500 = covprob_F_qlr(:,ind);

n = 250;
load(sprintf('MA_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_250= -b_V(1:na);
pi_abs_250 = covprob_F_abs(:,ind);
pi_qlr_250 = covprob_F_qlr(:,ind);

n = 100;
load(sprintf('MA_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_100= -b_V(1:na);
pi_abs_100 = covprob_F_abs(:,ind);
pi_qlr_100 = covprob_F_qlr(:,ind);

r  = rows (b0);
normal = 0.95*ones(r,1);
normalquantile_abs = 1.96*ones(r,1);
normalquantile_qlr = 3.84*ones(r,1);


%panel (a)
xmin = -15;
xmax = 0;
ymin = 0.5;
ymax = 1;
gridtick = 5;
gridtickY = 0.1;

subplot(1,2,1);
plot (b0,pi_abs0,'r-', b_500,pi_abs_500,'--',...
    b_250,pi_abs_250,'-.',b_100,pi_abs_100,'k:',...
    'LineWidth',2);
grid on;
axis([xmin,xmax,ymin,ymax]);
set(gca,'XDir','reverse')
title('(a) Standard |t| CI');
xlabel('b');       
set(gca,'XTick',xmin:gridtick:xmax);
set(gca,'YTick',ymin:gridtickY:ymax);
legend('Asy','n=500','n=250','n=100');
line (b0, normal, 'LineWidth',1.5, 'Color','k');



%panel (b)
xmin = -15;
xmax = 0;
ymin = 0.9;
ymax = 1;
gridtick = 5;
gridtickY = 0.02;
subplot(1,2,2);
plot (b0,pi_qlr0,'r-', b_500,pi_qlr_500,'--',...
    b_250,pi_qlr_250,'-.',b_100,pi_qlr_100,'k:',...
    'LineWidth',2);
grid on;
axis([xmin,xmax,ymin,ymax]);
set(gca,'XDir','reverse')
title('(b) Standard QLR CI');
xlabel('b');       %  add axis labels and plot title
set(gca,'XTick',xmin:gridtick:xmax);
set(gca,'YTick',ymin:gridtickY:ymax);
legend('Asy','n=500','n=250','n=100');
line (b0, normal, 'LineWidth',1.5, 'Color','k');

saveas(gcf,'AC_Figure_S7.fig');

pi_true = 0.7;
TN1 = round(pi_true*100);
%% Generate Data for Figures S-8 and S-9.
%% Figures S-8 and S-8 are the same as Figure 6 and the first row of
%% Figure 7, respectively, but with pi_true - 0.7 rather than 0.
ARMA_Asy(pi_true, m, pi_H); % simulate asymptotic results, save file ARMA_Asy_TN1.mat
n=500;
MA_F(pi_true, n, m, pi_H,rho_H); % simulate finite-sample results, save file MA_F_n_TN1.mat
n=250;
MA_F(pi_true, n, m, pi_H,rho_H); 
n=100;
MA_F(pi_true, n, m, pi_H,rho_H); 

%% Figure S8. Coverage Probabilities of Standard |t| and QLR CI's for the Parameter pi in the ARMA(1,1) Model with pi_true = 0.7.
ind= 1; % 1 select the first column of the coverage prob vectors below, which is result for the standard CI.
load(sprintf('ARMA_Asy_%d.mat',TN1));
na = rows(covprob_asy_abs);
b0 = -b_V(1:na);
pi_abs0 = covprob_asy_abs(:,ind);
pi_qlr0 = covprob_asy_qlr(:,ind);

n = 500;
load(sprintf('MA_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_500= -b_V(1:na);
pi_abs_500 = covprob_F_abs(:,ind);
pi_qlr_500 = covprob_F_qlr(:,ind);

n = 250;
load(sprintf('MA_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_250= -b_V(1:na);
pi_abs_250 = covprob_F_abs(:,ind);
pi_qlr_250 = covprob_F_qlr(:,ind);

n = 100;
load(sprintf('MA_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_100= -b_V(1:na);
pi_abs_100 = covprob_F_abs(:,ind);
pi_qlr_100 = covprob_F_qlr(:,ind);

r  = rows (b0);
normal = 0.95*ones(r,1);
normalquantile_abs = 1.96*ones(r,1);
normalquantile_qlr = 3.84*ones(r,1);


%panel (a)
xmin = -15;
xmax = 0;
ymin = 0.5;
ymax = 1;
gridtick = 5;
gridtickY = 0.1;

subplot(1,2,1);
plot (b0,pi_abs0,'r-', b_500,pi_abs_500,'--',...
    b_250,pi_abs_250,'-.',b_100,pi_abs_100,'k:',...
    'LineWidth',2);
grid on;
axis([xmin,xmax,ymin,ymax]);
set(gca,'XDir','reverse')
title('(a) Standard |t| CI');
xlabel('b');       
set(gca,'XTick',xmin:gridtick:xmax);
set(gca,'YTick',ymin:gridtickY:ymax);
legend('Asy','n=500','n=250','n=100');
line (b0, normal, 'LineWidth',1.5, 'Color','k');



%panel (b)
xmin = -15;
xmax = 0;
ymin = 0.9;
ymax = 1;
gridtick = 5;
gridtickY = 0.02;
subplot(1,2,2);
plot (b0,pi_qlr0,'r-', b_500,pi_qlr_500,'--',...
    b_250,pi_qlr_250,'-.',b_100,pi_qlr_100,'k:',...
    'LineWidth',2);
grid on;
axis([xmin,xmax,ymin,ymax]);
set(gca,'XDir','reverse')
title('(b) Standard QLR CI');
xlabel('b');       %  add axis labels and plot title
set(gca,'XTick',xmin:gridtick:xmax);
set(gca,'YTick',ymin:gridtickY:ymax);
legend('Asy','n=500','n=250','n=100');
line (b0, normal, 'LineWidth',1.5, 'Color','k');

saveas(gcf,'AC_Figure_S8.fig');


%% Figure S-9. 
ind = 6; % the vector is organized as [std, LF, k=0, k=0.5, k=1, k=1.5,....], we report the 6th column for k=1.5
load(sprintf('ARMA_Asy_%d.mat',TN1));
na = rows(covprob_asy_abs);
b0 = -b_V(1:na);
pi_abs0 = covprob_asy_abs(:,ind);
pi_qlr0 = covprob_asy_qlr(:,ind);

n = 500;
load(sprintf('MA_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_500= -b_V(1:na);
pi_abs_500 = covprob_F_abs(:,ind);
pi_qlr_500 = covprob_F_qlr(:,ind);

n = 250;
load(sprintf('MA_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_250= -b_V(1:na);
pi_abs_250 = covprob_F_abs(:,ind);
pi_qlr_250 = covprob_F_qlr(:,ind);

n = 100;
load(sprintf('MA_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_100= -b_V(1:na);
pi_abs_100 = covprob_F_abs(:,ind);
pi_qlr_100 = covprob_F_qlr(:,ind);

r  = rows (b0);
normal = 0.95*ones(r,1);
normalquantile_abs = 1.96*ones(r,1);
normalquantile_qlr = 3.84*ones(r,1);

xmin = -15;
xmax = 0;
ymin = 0.9;
ymax = 1;
gridtick = 5;
gridtickY = 0.02;


%panel (a)
subplot(1,2,1);
plot (b0,pi_abs0,'r-', b_500,pi_abs_500,'--',...
    b_250,pi_abs_250,'-.',b_100,pi_abs_100,'k:',...
    'LineWidth',2);
grid on;
axis([xmin,xmax,ymin,ymax]);
set(gca,'XDir','reverse')
title('(a) Robust |t| CI, \pi_0=0');
xlabel('b');       %  add axis labels and plot title
set(gca,'XTick',xmin:gridtick:xmax);
set(gca,'YTick',ymin:gridtickY:ymax);
legend('Asy','n=500','n=250','n=100');
line (b0, normal, 'LineWidth',1.5, 'Color','k');

%panel (b)
subplot(1,2,2);
plot (b0,pi_qlr0,'r-', b_500,pi_qlr_500,'--',...
    b_250,pi_qlr_250,'-.',b_100,pi_qlr_100,'k:',...
    'LineWidth',2);
grid on;
axis([xmin,xmax,ymin,ymax]);
set(gca,'XDir','reverse')
title('(b) Robust QLR CI, \pi_0=0');
xlabel('b');       %  add axis labels and plot title
set(gca,'XTick',xmin:gridtick:xmax);
set(gca,'YTick',ymin:gridtickY:ymax);
legend('Asy','n=500','n=250','n=100');
line (b0, normal, 'LineWidth',1.5, 'Color','k');

saveas(gcf,'AC_Figure_S9.fig');




