%This program plots Figures S-11 to S-25 in 
%"Suppemental Material for Estimation and Inference with Weak, Semi-strong, and Strong
%Identification" by Donald Andrews and Xu Cheng

clear; clc;

%% Generate Data for Tables S-11 to S-25
pi_H = 0.85;
rho_H = 0.9;
rhoV = [0,0.4,0.8];
nV = [100, 250, 500];
m = 50000;

for i=1:3
    rho_true = rhoV(i);    
    ARMA_Asy(rho_true, m, pi_H); %If this program was run with results saved, it can be omitted to save time.
    for j=1:3
    n=nV(j);   
    AR_F(rho_true, n, m, pi_H,rho_H); 
    end
end

%% Figure S-11 to S-13
nameV = ['1','2','3'];
for i = 1:3
rho_true = rhoV(i);
name = nameV(i);
TN1 = round(rho_true*100);
n=250;
load(sprintf('ARMA_Asy_%d.mat',TN1));
load(sprintf('AR_F_%d_%d.mat',n,TN1));
bR = [0,2,4,12];
IR = [1,21,41,78]; %index of [0,2,4,12] in the grids considered (b_V vector)
xmin = -1;
xmax =1;
ymin = 0;
ymax = 6;
%asymptotic results, first row
A = TbM_piest;
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t);
B = A(k,:,:);
[o1,o2,m]=size(B);
B = reshape(B,m,1);
[nn,x]=hist(B,40);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','b','EdgeColor','b');
axis([xmin,xmax,ymin,ymax]);
title(sprintf('Asy, b=%d',b));
end

%finite-sample results, second row
C = Theta_M(:,3,:);
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t+4);
B = C(k,:,:);
[o1,o2,m]=size(B);
B = reshape(B,m,1);
[nn,x]=hist(B,40);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','r','EdgeColor','r');
axis([xmin,xmax,ymin,ymax]);
title(sprintf('n=250, b=%d',b));
end
saveas(gcf,sprintf('AC_Figure_S1%c.fig',name));
end


%% Figures S-14 to S-16
nameV = ['4','5','6'];
xmin = -10;
xmax = 10;
ymin = 0;
ymax = 0.5;
for i = 1:3
rho_true = rhoV(i);
name = nameV(i);
TN1 = round(rho_true*100);
n=250;
load(sprintf('ARMA_Asy_%d.mat',TN1));
load(sprintf('AR_F_%d_%d.mat',n,TN1));

A = TbM(:,3,:);
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t);
B = A(k,:,:);
[o1,o2,m]=size(B);
B = reshape(B,m,1);
[nn,x]=hist(B,100);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','b','EdgeColor','b');
axis([xmin,xmax,ymin,ymax]);
title(sprintf('Asy, b=%d',b));
xline = -10:0.01:10;
yline = 1/sqrt(2*pi)*exp(-xline.^2/2);
line (xline, yline, 'LineWidth',2, 'Color','k');
end

%finite-sample results, second row
C = TbM_F(:,3,:);
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t+4);
B = C(k,:,:);
[o1,o2,m]=size(B);
B = reshape(B,m,1);
[nn,x]=hist(B,100);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','r','EdgeColor','r');
axis([xmin,xmax,ymin,ymax]);
xline = -10:0.01:10;
yline = 1/sqrt(2*pi)*exp(-xline.^2/2);
line (xline, yline, 'LineWidth',2, 'Color','k');
title(sprintf('n=250, b=%d',b));
end
saveas(gcf,sprintf('AC_Figure_S1%c.fig',name));

end


%% Figures S-17 to S-19
nameV = ['7','8','9'];
xmin = 0;
xmax = 5;
ymin = 0;
ymax = 2;
for i = 1:3
rho_true = rhoV(i);
name = nameV(i);
TN1 = round(rho_true*100);
n=250;
load(sprintf('ARMA_Asy_%d.mat',TN1));
load(sprintf('AR_F_%d_%d.mat',n,TN1));
%asymptotic results, first row
A = TbM_qlr_pi;
for t = 1:4
k = IR(t);
b = bR(t);
subplot(2,4,t);
B = A(k,:,:);
[o1,o2,m]=size(B);
B = reshape(B,m,1);
[nn,x]=hist(B,100);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','b','EdgeColor','b');
axis([xmin,xmax,ymin,ymax]);
title(sprintf('Asy, b=%d',b));
xline = 0:0.01:5;
yline = chi2pdf(xline,1);
line (xline, yline, 'LineWidth',2, 'Color','k');
end

%finite-sample results, second row
C = TbM_qlr_pi_F(:,1,:);
for t = 1:4
k = IR(t);
b = bR(t);
axis([xmin,xmax,ymin,ymax]);
subplot(2,4,t+4);
B = C(k,:,:);
[o1,o2,m]=size(B);
B = reshape(B,m,1);
[nn,x]=hist(B,100);
delta_x = x(2)-x(1);
bar(x,nn./sum(nn)/delta_x,1); % <- percentage cum dist
h = findobj(gca,'Type','patch');
set(h,'FaceColor','r','EdgeColor','r');
axis([xmin,xmax,ymin,ymax]);
xline = 0:0.01:5;
yline = chi2pdf(xline,1);
line (xline, yline, 'LineWidth',2, 'Color','k');
title(sprintf('n=250, b=%d',b));
end

saveas(gcf,sprintf('AC_Figure_S1%c.fig',name));

end

%% Figures S-20 to S-22
nameV = ['0','1','2'];
for i = 1:3
rho_true = rhoV(i);
name = nameV(i);
TN1 = round(rho_true*100);
ind = 1; % 1 select the first column of the coverage prob vectors below, which is result for the standard CI.
load(sprintf('ARMA_Asy_%d.mat',TN1));
na = rows(covprob_asy_abs);
b0 = b_V(1:na);
pi_abs0 = covprob_asy_abs(:,ind);
pi_qlr0 = covprob_asy_qlr(:,ind);

n = 500;
load(sprintf('AR_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_500= b_V(1:na);
pi_abs_500 = covprob_F_abs(:,ind);
pi_qlr_500 = covprob_F_qlr(:,ind);

n = 250;
load(sprintf('AR_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_250= b_V(1:na);
pi_abs_250 = covprob_F_abs(:,ind);
pi_qlr_250 = covprob_F_qlr(:,ind);

n = 100;
load(sprintf('AR_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_100= b_V(1:na);
pi_abs_100 = covprob_F_abs(:,ind);
pi_qlr_100 = covprob_F_qlr(:,ind);

r  = rows (b0);
normal = 0.95*ones(r,1);
normalquantile_abs = 1.96*ones(r,1);
normalquantile_qlr = 3.84*ones(r,1);

%panel (a)
xmin = 0;
xmax = 15;
ymin = 0.5;
ymax = 1;
gridtick = 5;
gridtickY = 0.1;

subplot(1,2,1);
plot (b0,pi_abs0,'r-', b_500,pi_abs_500,'--',...
    b_250,pi_abs_250,'-.',b_100,pi_abs_100,'k:',...
    'LineWidth',2);
grid on;
axis([xmin,xmax,ymin,ymax]);
title('(a) Standard |t| CI');
xlabel('b');       
set(gca,'XTick',xmin:gridtick:xmax);
set(gca,'YTick',ymin:gridtickY:ymax);
legend('Asy','n=500','n=250','n=100');
line (b0, normal, 'LineWidth',1.5, 'Color','k');



%panel (b)
xmin = 0;
xmax = 15;
ymin = 0.9;
ymax = 1;
gridtick = 5;
gridtickY = 0.02;
subplot(1,2,2);
plot (b0,pi_qlr0,'r-', b_500,pi_qlr_500,'--',...
    b_250,pi_qlr_250,'-.',b_100,pi_qlr_100,'k:',...
    'LineWidth',2);
grid on;
axis([xmin,xmax,ymin,ymax]);
title('(b) Standard QLR CI');
xlabel('b');       %  add axis labels and plot title
set(gca,'XTick',xmin:gridtick:xmax);
set(gca,'YTick',ymin:gridtickY:ymax);
legend('Asy','n=500','n=250','n=100');
line (b0, normal, 'LineWidth',1.5, 'Color','k');

saveas(gcf,sprintf('AC_Figure_S2%c.fig',name));

end


%% Figures S-23 to S-25
nameV = ['3','4','5'];
for i = 1:3
rho_true = rhoV(i);
name = nameV(i);
TN1 = round(rho_true*100);
ind = 6; % the vector is organized as [std, LF, k=0, k=0.5, k=1, k=1.5,....], we report the 6th column for k=1.5
load(sprintf('ARMA_Asy_%d.mat',TN1));
na = rows(covprob_asy_abs);
b0 = b_V(1:na);
pi_abs0 = covprob_asy_abs(:,ind);
pi_qlr0 = covprob_asy_qlr(:,ind);

n = 500;
load(sprintf('AR_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_500= b_V(1:na);
pi_abs_500 = covprob_F_abs(:,ind);
pi_qlr_500 = covprob_F_qlr(:,ind);

n = 250;
load(sprintf('AR_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_250= b_V(1:na);
pi_abs_250 = covprob_F_abs(:,ind);
pi_qlr_250 = covprob_F_qlr(:,ind);

n = 100;
load(sprintf('AR_F_%d_%d.mat',n,TN1));
na = rows(covprob_F_abs);
b_100= b_V(1:na);
pi_abs_100 = covprob_F_abs(:,ind);
pi_qlr_100 = covprob_F_qlr(:,ind);

r  = rows (b0);
normal = 0.95*ones(r,1);
normalquantile_abs = 1.96*ones(r,1);
normalquantile_qlr = 3.84*ones(r,1);

xmin = 0;
xmax = 15;
ymin = 0.9;
ymax = 1;
gridtick = 5;
gridtickY = 0.02;


%panel (a)
subplot(1,2,1);
plot (b0,pi_abs0,'r-', b_500,pi_abs_500,'--',...
    b_250,pi_abs_250,'-.',b_100,pi_abs_100,'k:',...
    'LineWidth',2);
grid on;
axis([xmin,xmax,ymin,ymax]);
title('(a) Robust |t| CI');
xlabel('b');       %  add axis labels and plot title
set(gca,'XTick',xmin:gridtick:xmax);
set(gca,'YTick',ymin:gridtickY:ymax);
legend('Asy','n=500','n=250','n=100');
line (b0, normal, 'LineWidth',1.5, 'Color','k');

%panel (b)
subplot(1,2,2);
plot (b0,pi_qlr0,'r-', b_500,pi_qlr_500,'--',...
    b_250,pi_qlr_250,'-.',b_100,pi_qlr_100,'k:',...
    'LineWidth',2);
grid on;
axis([xmin,xmax,ymin,ymax]);
title('(b) Robust QLR CI');
xlabel('b');       %  add axis labels and plot title
set(gca,'XTick',xmin:gridtick:xmax);
set(gca,'YTick',ymin:gridtickY:ymax);
legend('Asy','n=500','n=250','n=100');
line (b0, normal, 'LineWidth',1.5, 'Color','k');

saveas(gcf,sprintf('AC_Figure_S2%c.fig',name));

end



