function ICS_AC = LIML_ICS(S, T, k, pi_null, Omega)
% This program computes the unrestricted identification category selection
% (ICS) statistic.
% INPUTS:
% S, T: S and T statistics defined in the paper
% k: constant kappa used in the type 2 robust CI
% pi_null: null value of the structural parameter pi
% Omega: variance matrix of the error terms
% OUTPUT:
% ICS_AC: unrestricted ICS statistic

% compute the asy distribution of A(h) in AC1
    b0 = [1,-pi_null]';    
    a0 = [pi_null,1]';

    e2 = [0,1]';
    c1 = (b0'*(Omega*b0))^(-1/2);
    c2 = (a0'*(Omega\a0))^(-1/2);
    c3 = sqrt(e2'*Omega*e2);
    c1_tild = c3*c1;
    c2_tild = c3*c2;

    d1 = b0*c1_tild;
    d2 = Omega\a0*c2_tild;
    D=[d1,d2];
    xi = D\e2; %inv(D)*e2
    xi1 = xi(1);
    xi2 = xi(2);
    
    ICS_AC = sqrt((xi1*S+xi2*T)'*(xi1*S+xi2*T)/k);