function  [LF_cv, tao_null_V, tao_unres_V,covprob_null, covprob_unres,LR_sort, cv_lam, rl,lambdaV] = LIML_LF(k, rho, K_V, m, UMatrix)
% This program computes the LF critical value and the size correction
% factors for the type 2 robust CI.
% INPUTS:
% k: number of IV
% rho: corr in error cov matrix
% K_V: vector of kappa values
% m: number of mulation repetitions
% Umatrix: random variables
% OUTPUTS:
% LF_cv: least favorable critical value
% tao_null_V: size correction factor with null-imposed ICS statistic
% tao_unres_V: size correction factor with unrestricted ICS statistic
% covprob_null: coverage probability of standard, LF, and robust CIs with null imposed ICS
% staistic
% covprob_null: coverage probability of standard, LF, and robust CI with the unrestricted
% ICS statistic
% LR_sort: realizations of the LR statistic
% rl: number of grid used to find the LF statistic
% lambdaV: grids of lambda over which the LF critical value is computed

alpha = 0.05; % nominal size
pi_null = 0; % null value of pi
omg11 = 1;
omg12 = rho;
omg22 =1;
Omega = [omg11, omg12; omg12, omg22]; % covariance matrix of reduced-from errors
lambda_end = 40; % largest lambda considered in the computation of the least favorable (LF) critical value
lambda_grid = 1; % grid in search for LF critical value

% Robust CI parameters
std_cv = 3.84;
c = 2; % the constant in the transition function for robust CI
ind = 1; % the parametric function for the transition function, 1 is logistic
adj = 0; % adj used to obtain tao1 when tao2 is 0
%% LF critival value and Size Correction Factors
lambdaV = 0:lambda_grid:lambda_end;
lambdaV = lambdaV';
rl = rows(lambdaV);

% LF is the 95% of the LR statistic, when beta is the true value, largest
% over lambda (pi). Hence, beta_0 = beta for LF crit val calculation
LR_M = zeros(rl, 1,m);
ICS_null_M = zeros(rl, 1,m);
ICS_unres_M = zeros(rl, 1,m);

for j = 1:m   % different simulation repetitions
    US = UMatrix(:,j);
    UT = UMatrix(:,j+m); 
    
    parfor i = 1:rl % different true values of lambda
    lambda = lambdaV(i);
    b_t = ones(k,1)*sqrt(lambda/k); % true value of b because lambda = b'b
    pi_t = pi_null; % calculation under the null
    [S, T] = LIML_ST (Omega, b_t, pi_t, pi_null, US, UT); 
    Qs = S'*S;
    Qt = T'*T;
    Qst = S'*T;
    LR = 1/2*(Qs - Qt + sqrt((Qs-Qt)^2+4*Qst^2));
    ICS_null = sqrt(T'*T/k);
    ICS_unres = LIML_ICS(S, T, k, pi_null, Omega);  
    
    LR_M(i,:,j) = LR;
    ICS_null_M (i,:,j) = ICS_null;
    ICS_unres_M (i,:,j) = ICS_unres;
    end 
    
end

% LF critical value
LR_sort = sort(LR_M, 3); % increase over m repetition
ind_crt = round(m*(1-alpha)); % the indicator of the crit value
cv_lam = LR_sort (:,:,ind_crt)'; % a rlx1 vector of the crit val
[LF_cv, bmax] = max(cv_lam); % LF crit val, bmax is the null-imposed version under the null pi=0

% size correction factors in type 2 robust CI
tao_null_V =[];
tao_unres_V =[];

parfor j = 1:cols(K_V);
    K = K_V(j);
    [tao_null, tao2_V]= sizecorr(LR_M, ICS_null_M, LF_cv, std_cv, K,c, ind, bmax, adj,alpha);
    [tao_unres, tao2_V]= sizecorr(LR_M, ICS_unres_M, LF_cv, std_cv, K,c, ind, bmax, adj,alpha);
    tao_null_V = [tao_null_V; tao_null]; % no of K_V *2
    tao_unres_V = [tao_unres_V; tao_unres];
end

%% coverage prob under the null
covprob_null =  covprob(LR_M, ICS_null_M, std_cv, LF_cv, K_V, tao_null_V, c,ind);
covprob_unres =  covprob(LR_M, ICS_unres_M, std_cv, LF_cv, K_V, tao_unres_V, c,ind);

nk = length(K_V);
tao_null_V = reshape(tao_null_V,1,nk*2);
tao_unres_V = reshape(tao_unres_V, 1,nk*2);

covprob_null = reshape(covprob_null,1,rl*(nk+2));
covprob_unres = reshape(covprob_unres,1,rl*(nk+2));

LR_sort = reshape(LR_sort,rl*m,1);











    
    
    
    


    
    












