%This program generates data in Tables S-I and S-II. It also generates
%LF_SizeCorrection.mat, which is included in the folder and used in
%the simulation for finite-sample results.


clear;clc;

%% Generate Data for Tables S1-S2
m = 50000;

pV1 = 0:0.05:0.6;
pV2 = 0.625:0.025:0.825;
pV = [pV1, pV2];
np = length(pV);
pi_H = 0.85;
for i = 1:np
    pi_true = pV(i);    
    ARMA_Asy(pi_true, m, pi_H)
end

%% Table 1
CV_t = zeros(1,np);
CV_qlr = zeros(1,np);
delta1_t = zeros(1,np);
delta2_t = zeros(1,np);
delta1_qlr = zeros(1,np);
delta2_qlr = zeros(1,np);

for i =1:np
    pi_true = pV(i);
    TN1 = round(pi_true*100);
    load(sprintf('ARMA_Asy_%d.mat',TN1));
    CV_t(i) = LF_cv_abs;
    CV_qlr(i) = LF_cv_qlr;
    delta1_t(i) = tao_V_abs(4,1); %kappa =1.5 is the 4th 
    delta2_t(i) = tao_V_abs(4,2);
    delta1_qlr(i) = tao_V_qlr(4,1);
    delta2_qlr(i) = tao_V_qlr(4,2);
end

Table_S1_t = [pV;CV_t; delta1_t; delta2_t];
Table_S1_qlr = [pV;CV_qlr; delta1_qlr; delta2_qlr];
Table_S1 = [Table_S1_t; Table_S1_qlr];

%% Table 2
pV2 = 0:0.1:0.8;
CP_t=zeros(1,9);
CP_qlr = zeros(1,9);
for i=1:9
    pi_true = pV2(i);
    TN1 = round(pi_true*100);
    load(sprintf('ARMA_Asy_%d.mat',TN1));
    CP_t(i) = min(covprob_asy_abs(:,6));
    CP_qlr(i) = min(covprob_asy_qlr(:,6));
end

Table_S2 = [pV2;CP_t;CP_qlr];
avg = mean(Table_S2,2);
Table_S2 = [Table_S2, avg];

save('Tables_S1_S2.mat', 'Table_S1', 'Table_S1_t', 'Table_S1_qlr', 'Table_S2');

%% LF_SizeCorrection.mat include the following variables
nk = length(K_V);
np = np -1; %0.825 is not considered in the false coverage probability calculation because it is too close to the boundary
pV = pV(1,1:np);
LF_abs_piV = zeros(2,np);
LF_qlr_piV = zeros(2,np);
LF_abs_piV(1,:) = pV;
LF_qlr_piV(1,:) = pV;
abs_tau1 = zeros(nk,np);
abs_tau2 = zeros(nk,np);
qlr_tau1 = zeros(nk,np);
qlr_tau2 = zeros(nk,np);

for i =1:np
    pi_true = pV(i);
    TN1 = round(pi_true*100);
    load(sprintf('ARMA_Asy_%d.mat',TN1));
    
    LF_abs_piV(2,i) = LF_cv_abs;
    LF_qlr_piV(2,i) = LF_cv_qlr;
    abs_tau1(:,i) = tao_V_abs(:,1);
    abs_tau2(:,i) = tao_V_abs(:,2);
    qlr_tau1(:,i) = tao_V_qlr(:,1);
    qlr_tau2 (:,i)= tao_V_qlr(:,2);
    
end
% This shows how the included data file LF_SizeCorrection_generated.mat is
% generated.

save('LF_SizeCorrection.mat', 'LF_abs_piV', 'LF_qlr_piV','abs_tau1','abs_tau2',...
    'qlr_tau1','qlr_tau2');





