% This program generates data in Tables S-V to S-X.
% Note: Run program Table_S1_S2.mat first because this program uses values
% simulated there.

clear; clc;

rho_V = 0:0.01:0.8; % null values of pi and rho considered
%We start with this relatively course grid. For a few parameter
%specifications, this grid is not fine enough to find a null value for which
%the false coverage probability is between 0.48 to 0.52. In these cases, we
%refine the grid to 0.001.

n=500;
m = 50000;
pi_H = 0.85;
rho_H = 0.9;

%% MA Parameter
piV = [0, 0.4, 0.7];
b_VV = [2,5,10,20]';

absV = []; qlr = []; abs_pi = []; qlr_pi = []; abs_ss = [];
for i= 1:length(piV);
    pi_true = piV(i);
    TN1 = pi_true*10;
    [FCP_abs_V, FCP_qlr_V, FCP_abs_short_V, pi_abs_null_value_V, pi_qlr_null_value_V] ...
        = fcp(pi_true,rho_V,b_VV, n, m, pi_H, rho_H,1); % 1 indicates this is for the MA parameter

    FCP_abs_V = FCP_abs_V';
    FCP_qlr_V = FCP_qlr_V';
    FCP_abs_short_V = FCP_abs_short_V';
    pi_abs_null_value_V=pi_abs_null_value_V';
    pi_qlr_null_value_V=pi_qlr_null_value_V';

    absV = [absV, FCP_abs_V];
    qlr = [qlr, FCP_qlr_V];

    abs_pi = [abs_pi, pi_abs_null_value_V];
    qlr_pi = [qlr_pi, pi_qlr_null_value_V];

    abs_ss = [abs_ss, FCP_abs_short_V];
end

abs_full = [abs_pi;absV];
qlr_full = [qlr_pi;qlr];

abs_full_avg = mean(abs_full,2);
qlr_full_avg = mean(qlr_full,2);
abs_ss_avg = mean(abs_ss,2);

long_table_abs = [abs_full, abs_full_avg];
long_table_qlr = [qlr_full, qlr_full_avg];

short_table = [abs_ss, abs_ss_avg]; %This includes all rows

short_table_ss = [long_table_qlr(1,:);short_table(1,:);...
    short_table(5,:);long_table_qlr(2,:);long_table_qlr(6,:)];

Table_S5 = short_table_ss; %first row is the null value for which FCP is calculated
Table_S7 = long_table_abs;
Table_S8 = long_table_qlr;


%% AR Parameter
piV = [0, 0.4, 0.8];
b_VV = [2,5,10,20]';
absV = []; qlr = []; abs_pi = []; qlr_pi = []; abs_ss = [];
for i= 1:length(piV);
    pi_true = piV(i);
    TN1 = pi_true*10;
    [FCP_abs_V, FCP_qlr_V, FCP_abs_short_V, pi_abs_null_value_V, pi_qlr_null_value_V] ...
        = fcp(pi_true,rho_V,b_VV, n, m, pi_H, rho_H,2); % 2 indicates it is AR parameter

    FCP_abs_V = FCP_abs_V';
    FCP_qlr_V = FCP_qlr_V';
    FCP_abs_short_V = FCP_abs_short_V';
    pi_abs_null_value_V=pi_abs_null_value_V';
    pi_qlr_null_value_V=pi_qlr_null_value_V';

    absV = [absV, FCP_abs_V];
    qlr = [qlr, FCP_qlr_V];

    abs_pi = [abs_pi, pi_abs_null_value_V];
    qlr_pi = [qlr_pi, pi_qlr_null_value_V];

    abs_ss = [abs_ss, FCP_abs_short_V];
end

abs_full = [abs_pi;absV];
qlr_full = [qlr_pi;qlr];

abs_full_avg = mean(abs_full,2);
qlr_full_avg = mean(qlr_full,2);
abs_ss_avg = mean(abs_ss,2);

long_table_abs = [abs_full, abs_full_avg];
long_table_qlr = [qlr_full, qlr_full_avg];

short_table = [abs_ss, abs_ss_avg]; %This includes all rows

short_table_ss = [long_table_qlr(1,:);short_table(1,:);...
    short_table(5,:);long_table_qlr(2,:);long_table_qlr(6,:)];

Table_S6 = short_table_ss; %first row is the null value for which FCP is calculated
Table_S9 = long_table_abs;
Table_S10 = long_table_qlr;

save('Tables_S5_to_S10.mat', 'Table_S5','Table_S7','Table_S8',...
    'Table_S6','Table_S9','Table_S10');


