function Q_qlr = cf_asy_qlr(Z1, Z2, power, expt2, zeta_true, pi_true, b, pi, r_psi)
%This program calculates the ASYMPTOTIC STOCHASTIC PROCESS for the RESTRICTED maximum likelihood criterion function for the
%ARMA(1,1) model. The process is indexed by pi.
%by Donald Andrews and Xu Cheng
%INPUTS:
% Z1 is N(0,1) scalar
% Z2 is lz*1 N(0,1) vector, where lz = 100 is set in ARMA_Asy.m
% power = 1,2,3,...,length(Z2)
% expt2 is a quantity calculated in ARMA_Asy.m
% zeta_true: true value of zeta
% pi_true: true value of pi
% b: lim n^1/2*beta
% pi: argument of the process
% r_psi: selector matrix for the restrictions. For example, r_psi = [1,0]
% means beta is restricted at the true value.

% OUTPUT:
% Q_qlr: value of the asymptotic process for RESTRICTED MLE CF

%% G process 
G1 = pi.^(power -1)*Z2;
G2 = expt2*Z1;
G = [G1;G2];

%% H
H1 = 1-pi^2;
H2 = 2*zeta_true^2;
H_inv = diag([H1,H2]);
H = inv(H_inv);

%% K 
K1 = 1/(1-pi_true*pi)*b;
K = -[K1;0];

%% Xi process 
Q = -1/2*(G+K)'*H_inv*(G+K); 

%% QLR statistic
P_psi = H_inv*r_psi'*inv(r_psi*H_inv*r_psi')*r_psi;
tao = -H_inv*(G + K)-[b;0];
Q_add = 1/2*tao'*P_psi'*H*P_psi*tao;

Q_qlr = Q + Q_add;













