function Q = cf_asy_unres (Z1, Z2, power, expt2, zeta_true, pi_true, b, pi)
%This program calculates the ASYMPTOTIC STOCHASTIC PROCESS for the maximum likelihood criterion function for the
%ARMA(1,1) model. The process is indexed by pi.
%by Donald Andrews and Xu Cheng
%INPUTS:
% Z1 is N(0,1) scalar
% Z2 is lz*1 N(0,1) vector, where lz = 100 is set in ARMA_Asy.m
% power = 1,2,3,...,length(Z2)
% expt2 is a quantity calculated in ARMA_Asy.m
% zeta_true: true value of zeta
% pi_true: true value of pi
% b: lim n^1/2*beta
% pi: argument of the process

% OUTPUT:
% Q: value of the asymptotic process

%% G
G1 = pi.^(power-1)*Z2;
G2 = expt2*Z1;
G = [G1;G2];

%% H 
H1 = 1-pi^2;
H2 = 2*zeta_true^2;
H_inv = diag([H1,H2]);

%% K 
K1 = 1/(1-pi_true*pi)*b;
K = -[K1;0];

%%
Q = -1/2*(G+K)'*H_inv*(G+K); 












