function   covprob_rslt =  covprob(W, A, std_cv, LF_cv, K_V, tao_V, c,ind)
%This program calculates the coverage probability of the standard, least
%favorable, and type 2 robust CIs with various kappa values.
%by Donald Andrews and Xu Cheng
%INPUTS:
%W: test statistic
%A: ICS statistic
%std: standard crit val
%LF_cv: least favorable crit val
%K_V: a row vector of K values considered for the robust CI
%tao_V: tao1 and tao2 constants for size correction for all values in K_V
%c: constant in the smooth transition function for type-II robust CI
%ind: type of smooth transition function used, for details see sfn.m
%OUTPUT:
%covprob_rslt = [std, LF, rob_V];
%std: coverage prob for standard CIs (a vector over b values)
%LF: coverage prob for least favorable CIs (a vector over b values)
%rob_V: coverage prob for type-II robust CIs corresponding to K values in
%K_V (matrix over b and K values)

%% CIs with standard and least-favorable critical values
std = W<std_cv;
LF = W<LF_cv;
std = mean(std,3);
LF = mean(LF,3);

%% type-II robust CI

[r,cc] = size(K_V); % a row vector of K values
rob_V = [];

for i = 1:cc
  K = K_V(i); 
  tao1 = tao_V(i,1);
  tao2 = tao_V(i,2);
   
  LF_ad = W<(LF_cv +tao1);
  cv_smooth = std_cv + tao2+ (LF_cv+tao1-std_cv)*sfn(A,K,c,ind);
  std_ad = W< cv_smooth;
  
  K_ind = A<K; % use K to select
  rob_cov = LF_ad.*K_ind + std_ad.*(1-K_ind);
  rob_cov = mean(rob_cov,3);
  rob_V = [rob_V, rob_cov]; 
 
end

covprob_rslt = [std, LF, rob_V];









