function [FCP_abs_V, FCP_qlr_V, FCP_abs_short_V, pi_abs_null_value_V, pi_qlr_null_value_V] = fcp(pi_true,rho_V,b_VV, n, m, pi_H, rho_H,para_ind)
% This program computes the false coverage probability of type 2 robust CI for the MA (or AR) parameter.
% INPUTS:
% pi_true: true value of pi;
% rho_V: row vector of null values of pi
% b_VV: column vector of indicies of the b values considered
% n: sample size for simulation
% m: number of simulation repetitions
% pi_H : upper bound of pi parameter space
% rho_H : upper bound of rho parameter space
% para_ind: =1 for MA parameter and =2 for AR parameter
% OUTPUTS:
% FCP_abs_V: false coverage probability of the type 2 robust t CI.
% FCP_qlr_V: false coverage probability of the type 2 robust QLR CI.
% FCP_abs_short_V: fasle coverage probability reported in Table S-X for the MA parameter (S-XI
% if for the AR parameter).
% pi_abs_null_value_V: null value of pi under which the false coverage
% probability of the t robust CI is computed.
% pi_qlr_null_value_V: null vlaue of pi under which the false coverage
% probability of the QLR robust CI is computed.

rate = 0.5;
c = 0.5;
ind = 1;
K_V = [0,0.5,1,1.5,1.75,2.0,2.25,2.5,2.75,3,4,5,6,8,10];
K_ind = 7; % select the null value at kappa = 2

%% Load Data
load('LF_SizeCorrection.mat'); % otained in Tables_S1_S2.m

if para_ind ==1;
    [A_F, Q_FCP_M,t_FCP_M]= MA_FCP(pi_true, rho_V, b_VV, n, m, pi_H,rho_H);   
else
    [A_F, Q_FCP_M,t_FCP_M]= AR_FCP(pi_true, rho_V, b_VV, n, m, pi_H,rho_H);
end
    
%% calcuate size correction factors for all null values in rho_V vector
rhoV_true = [0:0.05:0.6,0.625:0.025:0.8]; % value we have for tau1 and tau2
bt = length(rhoV_true);
br = length(rho_V);
bk = length(K_V);

LF_absV = zeros(2,br); % the first row is the null value
LF_qlrV = zeros(2,br);
abs_tauV = zeros(bk,br,2);
qlr_tauV = zeros(bk,br,2);

% import from saved results of asymptotic simulation
abs_tau_M = cat(3,abs_tau1,abs_tau2); 
qlr_tau_M = cat(3,qlr_tau1,qlr_tau2); 

for k = 1:br  % for the kth value in the null vector    
    rho_0 = rho_V(k);
    rho_0_diff = rhoV_true - rho_0; % the difference
    
    sgn = (rho_0_diff<0); 
    sgn = sum(sgn); % number of true values in rhoV_true that is smaller than or equal to rho_0
    
    if sgn ==bt
        abs_tau = abs_tau_M(:,end,:);
        qlr_tau = qlr_tau_M(:,end,:);
        LF_abs_pi = LF_abs_piV(2,end);
        LF_qlr_pi = LF_qlr_piV(2,end);
    elseif sgn == 0
        abs_tau = abs_tau_M(:,1,:);
        qlr_tau = qlr_tau_M(:,1,:);
         LF_abs_pi = LF_abs_piV(2,1);
         LF_qlr_pi = LF_qlr_piV(2,1);        
    else
        
    %weight
    w1 = rho_0-rhoV_true(sgn); 
    w2 = rhoV_true(sgn+1)-rho_0;
    w = rhoV_true(sgn+1)-rhoV_true(sgn); 
    w1 = w1/w;
    w2 = w2/w;
       
    abs_tau =  abs_tau_M(:,sgn,:)*w2+abs_tau_M(:,sgn+1,:)*w1;
    qlr_tau =  qlr_tau_M(:,sgn,:)*w2+qlr_tau_M(:,sgn+1,:)*w1;
        
    LF_abs_pi = LF_abs_piV(2,sgn)*w2+LF_abs_piV(2,sgn+1)*w1;
    LF_qlr_pi = LF_qlr_piV(2,sgn)*w2+LF_qlr_piV(2,sgn+1)*w1;
       
    end
        
    LF_absV (:,k) = [rho_0;LF_abs_pi];
    LF_qlrV (:,k) = [rho_0;LF_qlr_pi];
    
    abs_tauV(:,k,:)=abs_tau; % first dim is kappa, second is null rho, third is tau1 or tau2
    qlr_tauV(:,k,:)=qlr_tau;
       
end

%% False Coverage Probability (FCP) for null values
pi_qlr_M = []; pi_abs_M = [];

for k = 1:length(b_VV)
    pi_qlr_V = []; pi_abs_V = [];
for t = 1:br % for each given null value
W_qlr = Q_FCP_M(k,t,:); % k is the row number that corresponds to b value
pre_VV = A_F(k,:,:);
std_cv = 3.84;
tao_qlr = [qlr_tauV(:,t,1),qlr_tauV(:,t,2)];
LF_qlr_pi = LF_qlrV(2,t);
pi_qlr =  covprob(W_qlr,pre_VV, std_cv, LF_qlr_pi, K_V, tao_qlr, c,ind); % this is a 1*17 row
pi_qlr_V = [pi_qlr_V,pi_qlr']; % each col is for a diff null value of pi, each row for a kappa value or std, LF for the first two

W_abs = abs(t_FCP_M(k,t,:)); 
std_cv = 1.96;
tao_abs = [abs_tauV(:,t,1),abs_tauV(:,t,2)];
LF_abs_pi = LF_absV(2,t);
pi_abs =  covprob(W_abs,pre_VV, std_cv, LF_abs_pi, K_V, tao_abs, c,ind); % this is a 1*17 row
pi_abs_V = [pi_abs_V,pi_abs']; % each col is for a diff null value, each row for a kappa value or std, LF for the first two

end

pi_qlr_M = cat(3,pi_qlr_M,pi_qlr_V); % over different b values
pi_abs_M = cat(3,pi_abs_M,pi_abs_V);

end

%both pi_qlr_M and pi_abs_M are three-dim matrix, where the first dim is
%kappa, the second dim is null pi, and the third dim is b

%% To deal with boundary problem, find where 0 and 0.8 are in the null vals
dif_0 = abs(rho_V -0);
dif_8 = abs(rho_V - 0.8);
dif_true = abs(rho_V - pi_true);
for i = 1:br
    if dif_0(i)<0.0001
        ind_0=i;
    end
    if dif_8(i)<0.0001
        ind_8 =i;
    end
    if dif_true(i)<0.0001
        true_id = i;
    end
end
%ind_0 and ind_8 are the index for 0 and 0.8
     
%% find the null value
pi_qlr_dif = abs(pi_qlr_M-rate);
pi_abs_dif = abs(pi_abs_M-rate);

pi_qlr_null_V = []; pi_abs_null_V = []; 
pi_qlr_null_value_V = []; pi_abs_null_value_V = [];


for k = 1:length(b_VV)
    % QLR
    pi_qlr_dif0 = pi_qlr_dif(K_ind,:,k); % kappa = 2, any null, b = given value
    pi_qlr_dif02 = pi_qlr_dif0(:,1:true_id,:);
    
    [min_qlr, b_qlr] = min(pi_qlr_dif0,[],2);
    [min_qlr2, b_qlr2] = min(pi_qlr_dif02,[],2);
    
    if min_qlr > 0.55 % in this case, the nearest to 0.5 is achieved at a boundary. 
        %The threshold is set to be 0.55 because we allow the smallest value to be different from 0.5 due to the grid search     
        fcp0 = pi_qlr_M(K_ind,ind_0,k);
        fcp8 = pi_qlr_M(K_ind,ind_8,k);        
        if fcp0 <fcp8            
            pi_qlr_null = ind_0;
        else pi_qlr_null = ind_8;
        end
    elseif rho_V(b_qlr)>pi_true && pi_true >0 %take the null value that is smaller than the true value     
        pi_qlr_null = b_qlr2;
    else
        pi_qlr_null = b_qlr;
    end
      
    pi_qlr_null_value = rho_V(pi_qlr_null);
    pi_qlr_null_V = [pi_qlr_null_V, pi_qlr_null]; %these are the indices
    pi_qlr_null_value_V = [pi_qlr_null_value_V, pi_qlr_null_value];
      
    % t
    pi_abs_dif0 = pi_abs_dif(K_ind,:,k); % kappa = 2, any null, b = given value
    pi_abs_dif02 = pi_abs_dif0(:,1:true_id,:);
    
    [min_abs, b_abs] = min(pi_abs_dif0,[],2);
    [min_abs2, b_abs2] = min(pi_abs_dif02,[],2);
    
    
    if min_abs > 0.55        
        fcp0 = pi_abs_M(K_ind,ind_0,k);
        fcp8 = pi_abs_M(K_ind,ind_8,k);
        if fcp0 <fcp8            
            pi_abs_null = ind_0;
        else pi_abs_null = ind_8;
        end
        
    elseif rho_V(b_abs)>pi_true && pi_true>0
         pi_abs_null = b_abs2;
    else pi_abs_null = b_abs;
    end  
    
    pi_abs_null_value = rho_V(pi_abs_null);
    pi_abs_null_V = [pi_abs_null_V, pi_abs_null];
    pi_abs_null_value_V = [pi_abs_null_value_V, pi_abs_null_value];
        
end

% pi_abs_null_V and pi_qlr_null_V are row vectors for the selection of
% null value, the index of the null value

%% FCP at the given null value
FCP_abs_V = []; FCP_qlr_V = []; FCP_abs_short_V = [];

for k = 1:length(b_VV)
    pi_abs_null = pi_abs_null_V(k);
    FCP_abs = pi_abs_M(:,pi_abs_null,k);
    
    pi_qlr_null = pi_qlr_null_V(k);
    FCP_qlr = pi_qlr_M(:,pi_qlr_null,k);
    
    FCP_abs_short = pi_abs_M(:,pi_qlr_null,k); % in the short table, the selection is based on qlr results
    
    FCP_abs_V = [FCP_abs_V, FCP_abs];
    FCP_qlr_V = [FCP_qlr_V, FCP_qlr];
    FCP_abs_short_V = [FCP_abs_short_V, FCP_abs_short];
    
    
end
    
    % First row is standard CI, deleted
    FCP_abs_V = FCP_abs_V(2:end,:)';
    FCP_qlr_V = FCP_qlr_V(2:end,:)';
    FCP_abs_short_V = FCP_abs_short_V (2:end,:)';
    pi_abs_null_value_V=pi_abs_null_value_V';
    pi_qlr_null_value_V=pi_qlr_null_value_V';
  

