function p = rejprob(W,A,sup_q1,std_cv,K,tao1,tao2,c,ind)
%This program calculates the rejection probability of the robust test for a
%given kappa value.
%by Donald Andrews and Xu Cheng
%INPUTS:
% W: test statistic
% A: identification-category-selection (ICS) statistic
% sup_q1: least favorable critical value over b
% std_cv: standard critical value at b=inf
% K: constant in ICS
% (tao1,tao2): constants for size correction in type-II robust test
% c: constant in the smooth parameteric function in type-II robust test
% ind: parametric function used in ICS for the type-II robust test
% e.g., ind=1, s(x) = exp(-cx)
%       ind=2, s(x) = 1/(1+cx)
%       ind=3, s(x) = 1(x<=0)
%OUTPUTS:
%p: rejection probability

sup_q = sup_q1 + tao1;
p1 = W > sup_q; 
p1 = mean(p1,3); %results from different simulation repetition are stacked over the 3rd dimension so that the mean is the rejection prob

cv2 = std_cv + tao2+ (sup_q-std_cv)*sfn(A,K,c,ind);
p2 = (W>cv2).*(W <= sup_q).*(A > K);
p2 = mean(p2,3);

p=p1+p2;