function [tao, tao2_V]= sizecorr(Wh, Ah, sup_q1, std_cv, K,c,ind,bmax,adj,alpha)
%This program calculates the constants used for size correction for the type 2 robust CI. 
%by Donald Andrews and Xu Cheng
%INPUTS: 
% Wh : three-dim matrix of test statistics
% Ah : three-dim matrix of identification-category-selection (ICS) statistic
% sup_q1: least favorable crit val
% std_cv: standard crit value
% K: constant in ICS
% c: constant in the smooth parameteric function in type-II robust test
% ind: parametric function used in ICS for the type-II robust test
% e.g., ind=1, s(x) = exp(-cx)
%       ind=2, s(x) = 1/(1+cx)
%       ind=3, s(x) = 1(x<=0)
% bmax: row index in the grids vector b_V where the least favorable crit value is achieved
% adj: adjustment in b used in the calculation of tao1
% alpha: size of test
% OUTPUTS: 
% tao = [tao1, tao2]: size correction constants
% tao2_V: a vector of tao2 correspond to different b values, tao is the
% largest value of this vector

tao1_start = 0;
tao1_H = 1000;
tao1_L = 0;
[nh,nb,m] = size(Wh);
bmax = min(abs(bmax)+adj,nh);

%% calculate tao1

for i = 1: bmax;
W = Wh(i,:,:);
A = Ah (i,:,:);
tao2_base =0;

p_H = rejprob(W,A,sup_q1,std_cv,K,tao1_H,tao2_base,c,ind);%with a high tao1 value
p_L = rejprob(W,A,sup_q1,std_cv,K,tao1_L,tao2_base,c,ind);%with a low tao1 value

if p_H > alpha
    tao1 = tao1_H;
elseif p_L <= alpha  
    tao1 = tao1_L;
else

tao1 = 0;
tao2 = tao2_base;
grid_tao1 = 1;
p = rejprob(W,A,sup_q1,std_cv,K,tao1,tao2,c,ind);
delta = p-alpha; %this is positive, below we find tao1 to make delta =0

iter = 1;
iter2 = 1;

while delta > 1e-8 && grid_tao1>1e-10;
    while p>alpha;
tao1 = tao1+grid_tao1;
p = rejprob(W,A,sup_q1,std_cv,K,tao1,tao2,c,ind);
iter = iter +1;
    end
tao1 = tao1 -grid_tao1;
p = rejprob(W,A,sup_q1,std_cv,K,tao1,tao2,c,ind);
delta = p-alpha;
grid_tao1 = grid_tao1/10;  %make the value more accurate
iter2 = iter2 +1;
end
end

if tao1 > tao1_start
    tao1_start = tao1;
end

end

tao1 = tao1_start; %largest tao1 value obtained over b=b_V(1) to b_V(bmax+adj)

%% Calculate tao2, given tao1 and K
tao2_V = zeros(nh,1);

for i = 1:nh
   tao2 = tao2_base;
   W = Wh(i,:,:);
   A = Ah(i,:,:);
   
   p= rejprob(W,A,sup_q1,std_cv,K,tao1,tao2,c,ind);
   
   if p<=alpha
       tao2=tao2_base;
   else
       delta = p-alpha;
       grid_tao2 = 1;
       iter1 = 1;
       iter=1;
       
    while delta > 1e-8 && grid_tao2>1e-10
        while p>alpha
                tao2 = tao2+grid_tao2;
                p = rejprob(W,A,sup_q1,std_cv,K,tao1,tao2,c,ind);
                iter = iter+1;
        end
            tao2 = tao2 - grid_tao2;
            p = rejprob(W,A,sup_q1,std_cv,K,tao1,tao2,c,ind);
            delta = p-alpha;
            grid_tao2 = grid_tao2/10;
            iter1 = iter1+1;
    end
    end

tao2_V(i) = tao2;
end

tao2 = max(tao2_V);
tao = [tao1, tao2];

















    
    
    














